@@ -79,7 +79,7 @@ class NavWidget(ScrollableContainer, can_focus=True):
         self.text = text
 
     def compose(self) -> ComposeResult:
-        yield Static(self.text)
+        yield Static(self.text, markup=False)
 
     def watch_text(self) -> None:
         self.query_one(Static).update(self.text)
@@ -95,7 +95,7 @@ class Info(Widget, can_focus=False):
         self.text = text
 
     def compose(self) -> ComposeResult:
-        yield Static(self.text)
+        yield Static(self.text, markup=False)
 
     def watch_text(self) -> None:
         self.query_one(Static).update(self.text)
