@@ -188,7 +188,9 @@ class APRProof(Proof[APRProofStep, APRProofResult], KCFGExploration):
                         shortest_path.append(succ.source)
 
             nonzero_depth = self.nonzero_depth(node)
-            module_name = self.circularities_module_name if nonzero_depth else self.dependencies_module_name
+            module_name = (
+                self.circularities_module_name if nonzero_depth and self.circularity else self.dependencies_module_name
+            )
 
             predecessor_edges = self.kcfg.edges(target_id=node.id)
             predecessor_node_id: NodeIdLike | None = (
@@ -773,10 +775,11 @@ class APRProver(Prover[APRProof, APRProofStep, APRProofResult]):
             if isinstance(subproof, APRProof)
             for rule in subproof.as_rules(priority=20, direct_rule=self.direct_subproof_rules)
         ]
-        circularity_rule = proof.as_rule(priority=20)
-
         _inject_module(proof.dependencies_module_name, main_module_name, dependencies_as_rules)
-        _inject_module(proof.circularities_module_name, proof.dependencies_module_name, [circularity_rule])
+
+        if proof.circularity:
+            circularity_rule = proof.as_rule(priority=20)
+            _inject_module(proof.circularities_module_name, proof.dependencies_module_name, [circularity_rule])
 
         for node_id in [proof.init, proof.target]:
             if self.kcfg_explore.kcfg_semantics.is_terminal(proof.kcfg.node(node_id).cterm):
